mysql.stmt.bind_in.In_Tiny_Int

Package mysql :: Package stmt :: Module bind_in :: Class In_Tiny_Int |
[hide private]
[frames] | no frames]

# Class In_Tiny_Int

    object --+
             |
    Input_Bind --+
                 |
                In_Tiny_Int

Known Subclasses:
  In_Bool

TINYINT input binding.

The value should be an integer.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `Input_Bind`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e5f0>`

Instance Variables | [hide private]
Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Input_Bind.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e5f0>